@@ -25,17 +25,20 @@ const Lang = imports.lang;
 
 const Application = imports.application;
 const PlaceStore = imports.placeStore;
+const TransitOptions = imports.transitOptions;
 
 const Transportation = {
     CAR:        0,
     BIKE:       1,
     PEDESTRIAN: 2,
+    TRANSIT:    3,
 
     toString: function (transportation) {
         switch(transportation) {
         case Transportation.CAR:        return 'car';
         case Transportation.BIKE:       return 'bike';
         case Transportation.PEDESTRIAN: return 'foot';
+        case Transportation.TRANSIT:    return 'transit';
         default:                        return null;
         }
     }
@@ -90,7 +93,8 @@ const RouteQuery = new Lang.Class({
                                                 GObject.ParamFlags.WRITABLE,
                                                 Transportation.CAR,
                                                 Transportation.PEDESTRIAN,
-                                                Transportation.CAR)
+                                                Transportation.CAR,
+                                                Transportation.TRANSIT)
     },
 
     get points() {
@@ -112,9 +116,57 @@ const RouteQuery = new Lang.Class({
         return this._latest;
     },
 
+    get time() {
+        return this._time;
+    },
+
+    /* time to leave or arrive, null implies "Leave now" */
+    set time(time) {
+        this._time = time;
+        this.notify('points');
+    },
+
+    get date() {
+        return this._date;
+    },
+
+    /* date to leave or arrive */
+    set date(date) {
+        this._date = date;
+        /* only notify change when an actual date was set, when resetting time
+         * time and date (to use "Leave Now" routing) time would be set to null
+         * triggering an update */
+        if (date)
+            this.notify('points');
+    },
+
+    get arriveBy() {
+        return this._arriveBy;
+    },
+
+    /* when set to true, the set time and date means arrive by the specified
+     * time */
+    set arriveBy(arriveBy) {
+        this._arriveBy = arriveBy;
+        if (this._time)
+            this.notify('points');
+    },
+
+    get transitOptions() {
+        return this._transitOptions;
+    },
+
+    set transitOptions(options) {
+        this._transitOptions = options;
+        this.notify('points');
+    },
+
     _init: function(args) {
         this.parent(args);
         this._points = [];
+        this._time = null;
+        this._date = null;
+        this._transitOptions = new TransitOptions.TransitOptions();
         this.reset();
     },
 
